@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-file-chooser.c 8322 2008-06-30 18:21:59Z chpe $
+ *  $Id$
  */
 
 #include "config.h"
@@ -30,8 +30,7 @@
 #include "ephy-stock-icons.h"
 #include "ephy-string.h"
 
-#include <gtk/gtkstock.h>
-#include <gtk/gtkimage.h>
+#include <gtk/gtk.h>
 #include <glib/gi18n.h>
 
 #define EPHY_FILE_CHOOSER_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_FILE_CHOOSER, EphyFileChooserPrivate))
@@ -375,6 +374,9 @@ ephy_file_chooser_new (const char *title,
 	 * _after_ our instance_init and construct-param setters will have
 	 * run.
 	 */
+
+        gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dialog), g_get_home_dir ());
+
 	if (persist_key != NULL)
 	{
 		ephy_file_chooser_set_persist_key (dialog, persist_key);
