@@ -49,8 +49,7 @@
 
 #include <string.h>
 #include <glib/gi18n.h>
-#include <gtk/gtkmain.h>
-
+#include <gtk/gtk.h>
 
 #define BM_WINDOW_DATA_KEY "bookmarks-window-data"
 
@@ -118,7 +117,7 @@ activate_bookmark_properties (GtkAction *action,
 
 	widget = gtk_widget_get_ancestor (egg_editable_toolbar_get_selected (etoolbar),
 					  GTK_TYPE_TOOL_ITEM);
-	baction = widget ? g_object_get_data (G_OBJECT (widget), "gtk-action") : NULL;
+	baction = widget ? gtk_widget_get_action (widget) : NULL;
 	g_return_if_fail (EPHY_IS_BOOKMARK_ACTION (baction));
 
 	ephy_bookmarks_ui_show_bookmark (ephy_bookmark_action_get_bookmark
@@ -134,7 +133,7 @@ activate_bookmark_open_tab (GtkAction *action,
 
 	widget = gtk_widget_get_ancestor (egg_editable_toolbar_get_selected (etoolbar),
 					  GTK_TYPE_TOOL_ITEM);
-	baction = widget ? g_object_get_data (G_OBJECT (widget), "gtk-action") : NULL;
+	baction = widget ? gtk_widget_get_action (widget) : NULL;
 	g_return_if_fail (EPHY_IS_BOOKMARK_ACTION (baction));
 
 	ephy_bookmark_action_activate (EPHY_BOOKMARK_ACTION (baction), widget,
@@ -150,7 +149,7 @@ activate_bookmark_open_window (GtkAction *action,
 
 	widget = gtk_widget_get_ancestor (egg_editable_toolbar_get_selected (etoolbar),
 					  GTK_TYPE_TOOL_ITEM);
-	baction = widget ? g_object_get_data (G_OBJECT (widget), "gtk-action") : NULL;
+	baction = widget ? gtk_widget_get_action (widget) : NULL;
 	g_return_if_fail (EPHY_IS_BOOKMARK_ACTION (baction));
 
 	ephy_bookmark_action_activate (EPHY_BOOKMARK_ACTION (baction), widget,
@@ -172,7 +171,7 @@ selected_bookmark_action (EggEditableToolbar *etoolbar,
 	{
 		widget = egg_editable_toolbar_get_selected (etoolbar);
 		widget = widget ? gtk_widget_get_ancestor (widget, GTK_TYPE_TOOL_ITEM) : NULL;
-		baction = widget ? g_object_get_data (G_OBJECT (widget), "gtk-action") : NULL;
+		baction = widget ? gtk_widget_get_action (widget) : NULL;
 		visible = EPHY_IS_BOOKMARK_ACTION (baction);
 	}
 	  
